# 报警系统数据字典

报警中心提供一份标准的字典，如果不满足项目上的使用需求，项目上可以自己定义字典。
但需要保证项目自定义的字典和报警中心使用的是同样的编码。如果需要新增编码，请务必和报警中心开发人员确认。

## 报警类型（alarm_category）

```java
public enum EnumAlarmCategory {
    EQ("Eq", "设备报警"),
    SP("Sp", "空间报警"),
    SY("Sy", "系统报警"),
    SAFE("Safe", "安全报警"),
    RUN("Run", "高效运行报警"),
    ENV("Env", "环境报警"),
    ENERGY("Energy", "能源报警"),
    TENANT("Tenant", "租户报警"),
    ELECTRIC("Electric", "配电报警"),
    BIM("Bim", "BIM报警");

    @Setter
    @Getter
    private String type;

    @Setter
    @Getter
    private String desc;
}
```

## 报警等级 (alarm_level)

```java
public enum EnumAlarmLevel {
    S("S", "高"),
    A("A", "中"),
    B("B", "低");

    @Setter
    @Getter
    private String type;

    @Setter
    @Getter
    private String desc;
}
```

## 报警性质 (alarm_nature)

```java
public enum EnumAlarmNature {
    MISTAKE(1, "误报"),
    TRUE(2, "真实报警"),
    TEST(3, "测试报警");

    @Setter
    @Getter
    private Integer type;

    @Setter
    @Getter
    private String desc;
}
```

## 报警状态 (alarm_state)

```java
public enum EnumAlarmState {
    UN_HANDLE(1, "未恢复"),
    END(2, "已恢复"),
    EXPIRE(3, "已过期");

    @Setter
    @Getter
    private Integer type;

    @Setter
    @Getter
    private String desc;
}
```

## 报警处理方式 (alarm_treat_mode)

```java
public enum EnumAlarmTreatMode {
    IGNORE(1, "忽略"),
    ORDER(2, "转工单"),
    CLOSE(3, "关闭报警");

    @Setter
    @Getter
    private Integer type;

    @Setter
    @Getter
    private String desc;
}
```

## 报警处理状态 (alarm_treat_state)

```java
public enum EnumAlarmTreatState {
    UN_HANDLE(1, "未处理"),
    HANDLING(2, "处理中"),
    DONE(3, "处理完成"),
    // 用于兼容子系统业务，后期会移除该状态
    IGNORE(4, "已忽略");

    @Setter
    @Getter
    private Integer type;

    @Setter
    @Getter
    private String desc;
}
```

## 报警条目

|编码|名称|
|----|----|
|2001|计划一致性报警-设备多开|
|2002|计划一致性报警-设备少开|
|2003|计划一致性报警-异常开启|
|2004|计划一致性报警-异常关闭|
|2005|历史一致性报警-设备多开|
|2006|历史一致性报警-设备少开|
|2007|历史一致性报警-异常开启|
|2008|历史一致性报警-异常关闭|
